@@ -1,15 +1,21 @@
 package HTML::FormFu::Deflator::Strftime;
 
-use strict;
-use base 'HTML::FormFu::Deflator';
+use Moose;
+extends 'HTML::FormFu::Deflator';
 
-__PACKAGE__->mk_item_accessors( qw( strftime ) );
+has strftime => ( is => 'rw', traits => ['Chained'] );
 
 sub deflator {
     my ( $self, $value ) = @_;
 
     my $return;
 
+    eval {
+        my $locale = $self->locale;
+
+        $value->set_locale($locale) if defined $locale;
+    };
+
     eval { $return = $value->strftime( $self->strftime ) };
 
     if ($@) {
@@ -19,6 +25,8 @@ sub deflator {
     return $return;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -57,6 +65,8 @@ This deflator calls L<DateTime>'s C<strftime> method. Possible values for
 the format string are documented at
 L<http://search.cpan.org/dist/DateTime/lib/DateTime.pm#strftime_Patterns>.
 
+If you set the form's locale (see L<HTML::FormFu/locale>) this is set on the DateTime object. Now you can use C<%x> to get the default date or C<%X> for the default time for the object's locale.
+
 =head1 AUTHOR
 
 Carl Franks, C<cfranks@cpan.org>
