@@ -2,6 +2,7 @@ package HTML::FormFu::Deploy;
 
 use strict;
 
+use HTML::FormFu::Constants qw( $EMPTY_STR );
 use Cwd qw( getcwd );
 use Fatal qw( open binmode close mkdir );
 use File::Copy qw( copy move );
@@ -35,8 +36,8 @@ sub file_list {
     my @dir;
 
     my $wanted = sub {
-        return if /^\./;    # skip files beginning with "."
-        return unless -f $File::Find::name;    # skip non-files
+        return if /^\./;                    # skip files beginning with "."
+        return if !-f $File::Find::name;    # skip non-files
 
         # necessary when using dev files
         return if $File::Find::name =~ m|/\.svn|;
@@ -55,13 +56,13 @@ sub file_source {
 
     my $path = File::Spec->catfile( $SHARE_DIR, $filename );
 
-    croak "unknown filename: '$path'" unless -f $path;
+    croak "unknown filename: '$path'" if !-f $path;
 
     open my $fh, '<', $path;
 
     my $data = do { local $/; <$fh> };
 
-    $data = "" if !defined $data;
+    $data = $EMPTY_STR if !defined $data;
 
     close $fh;
 
@@ -104,4 +105,6 @@ sub deploy {
     return;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
