@@ -1,33 +1,41 @@
 package HTML::FormFu::Element::Repeatable;
 
-use strict;
-use base 'HTML::FormFu::Element::Block';
+use Moose;
+extends 'HTML::FormFu::Element::Block';
 
 use HTML::FormFu::Util qw( DEBUG_PROCESS debug );
-use Class::C3;
 use List::Util qw( first );
 use Carp qw( croak );
 
-__PACKAGE__->mk_item_accessors( qw(
-        _original_elements
-        increment_field_names
-        counter_name
-        repeatable_delimiter
-) );
+has counter_name       => ( is => 'rw', traits => ['Chained'] );
 
-sub new {
-    my $self = shift->next::method(@_);
+has _original_elements => ( is => 'rw' );
+
+has increment_field_names => (
+    is      => 'rw',
+    default => 1,
+    lazy    => 1,
+    traits  => ['Chained'],
+);
+
+# This attribute is currently not documented as FF::Model::HashRef
+# only supports '_'
+
+has repeatable_delimiter => (
+    is      => 'rw',
+    default => '_',
+    lazy    => 1,
+    traits  => ['Chained'],
+);
+
+after BUILD => sub {
+    my $self = shift;
 
     $self->filename('repeatable');
     $self->is_repeatable(1);
-    $self->increment_field_names(1);
-# TODO
-    # This setter is currently not documentes as FF::Model::HashRef
-    # only supports '_'
-    $self->repeatable_delimiter('_');
 
-    return $self;
-}
+    return;
+};
 
 sub repeat {
     my ( $self, $count ) = @_;
@@ -340,7 +348,7 @@ sub process {
         $self->repeat($count);
     }
 
-    return $self->next::method(@_);
+    return $self->SUPER::process(@_);
 }
 
 sub content {
@@ -371,6 +379,8 @@ sub string {
     return $html;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -455,7 +465,8 @@ If no argument C<$count> is provided, it defaults to C<1>.
 Note that C<< $form->process >> will call L</repeat> automatically to ensure the
 initial child elements are correctly set up - unless you call L</repeat>
 manually first, in which case the child elements you created will be left
-untouched (otherwise L</process> would overwrite your changes).
+untouched (otherwise L<process|HTML::FormFu/process> would overwrite your
+changes).
 
 Any subsequent call to L</repeat> will delete the previously copied elements
 before creating new copies - this means you cannot make repeated calls to
@@ -577,14 +588,14 @@ Calling C<< $element->repeat(2) >> would result in the following markup:
         <input name="my_rep.foo_2" type="text" />
     </span>
 
-See L<HTML::FormFu::Element::block/tag> for details.
+See L<HTML::FormFu::Element::Block/tag> for details.
 
 =head2 auto_id
 
 As well as the usual subtitutions, any instances of C<%r> will be
 replaced with the value of L</repeatable_count>.
 
-See L<HTML::FormFu::Element::block/auto_id> for further details.
+See L<HTML::FormFu::Element::Block/auto_id> for further details.
 
     ---
     elements:
@@ -638,3 +649,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
